
``rattail.commands.batch``
==========================

.. automodule:: rattail.commands.batch

   **Helper Functions**

   .. autofunction:: batch_action_command

   .. autofunction:: batch_action_command_template

   **Subcommands**

   .. autofunction:: auto_receive

   .. program-output:: rattail auto-receive --help

   .. autofunction:: execute_batch

   .. program-output:: rattail execute-batch --help

   .. autofunction:: make_batch

   .. program-output:: rattail make-batch --help

   .. autofunction:: populate_batch

   .. program-output:: rattail populate-batch --help

   .. autofunction:: purge_batches

   .. program-output:: rattail purge-batches --help

   .. autofunction:: refresh_batch

   .. program-output:: rattail refresh-batch --help
